### INTRODUCTION
> pymeili.為美麗而生 [remake edition]

pymeili is a module to beautify your python plot or terminal text with more simple way. the design idea is from Navigraph aeronautical chart.

### IMPORTANT
If you encounter the FileNotFound error when using this module, you need to manually install font-packages: https://dwl.freefontsfamily.com/download/futura/; 
moving the font file to installed module folder, for instance: `C:\Users\Username\AppData\Local\Programs\Python\Python311\Lib\site-packages\pymeili\resources`

If you encounter the ModuleNotFoundError when using this module, you need to manually install the module in the lastest version:
`pip install matplotlib`
`pip install numpy`
`pip install seaborn`
`pip install pathlib`
`pip install pathlib2`
`pip install metpy`
`pip install cartopy`
`pip install basemap`
Also, some modules do not support the previous version of python, make sure you are using the version 3.7 or above.
